@@ -18,6 +18,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.Constants;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
 import org.gcube.portlets.user.td.gwtservice.shared.task.InvocationS;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnViewData;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.ConditionCode;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.DimensionRow;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.RefColumn;
@@ -124,6 +125,7 @@ public class ReplaceBatchPanel extends FramedPanel implements
 	private ToolBar toolBarHead;
 
 	private ComboBox<ShowOccurrencesTypeElement> comboShowOccurrencesType = null;
+	private ListStore<ShowOccurrencesTypeElement> storeShowOccurrencesType;
 
 	private TextButton btnConnect;
 	private TextButton btnDisconnect;
@@ -200,11 +202,10 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		// Create Combo Show
 		ShowOccurrencesTypeProperties propsShowOccurrencesType = GWT
 				.create(ShowOccurrencesTypeProperties.class);
-		ListStore<ShowOccurrencesTypeElement> storeShowOccurrencesType = new ListStore<ShowOccurrencesTypeElement>(
+		storeShowOccurrencesType = new ListStore<ShowOccurrencesTypeElement>(
 				propsShowOccurrencesType.id());
-		storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
-				.getShowOccurrencesType());
-
+		
+		
 		comboShowOccurrencesType = new ComboBox<ShowOccurrencesTypeElement>(
 				storeShowOccurrencesType, propsShowOccurrencesType.label());
 		Log.trace("ComboMeasureType created");
@@ -261,6 +262,9 @@ public class ReplaceBatchPanel extends FramedPanel implements
 			connectionField = new TextField();
 			toolBarHead.add(connectionField);
 
+		} else {
+			connectionField = new TextField();
+			toolBarHead.add(connectionField);
 		}
 
 		// Create Grid
@@ -434,17 +438,8 @@ public class ReplaceBatchPanel extends FramedPanel implements
 				new Margins(5, 2, 5, 2)));
 		add(v);
 
-		if (!column.isViewColumn()) {
-			Log.debug("Not Is View Column");
-			connectionField.setVisible(false);
-			btnDisconnect.setVisible(false);
-
-		} else {
-			Log.debug("Is View Column");
-
-		}
-
 		if (curation) {
+			storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore.getShowOccurrencesType());
 			if (connection != null) {
 				Log.debug("Selected connection: " + connection);
 				connectionField.setValue(connection.getLabel());
@@ -452,8 +447,29 @@ public class ReplaceBatchPanel extends FramedPanel implements
 				btnDisconnect.setVisible(true);
 				btnConnect.setVisible(false);
 				btnConnect.enable();
+
+			} else {
+
+			}
+			toolBarHead.forceLayout();
+		} else {
+			if (column.isViewColumn()) {
+				Log.debug("Is View Column");
+				storeShowOccurrencesType
+						.add(ShowOccurrencesTypeStore.onlyErrorsElement);
+				ColumnViewData cViewData = column.getColumnViewData();
+				RefColumn refCol = new RefColumn(String.valueOf(cViewData
+						.getTargetTableId()),
+						cViewData.getTargetTableColumnId());
+				retrieveConnectionForViewColumn(refCol);
+			} else {
+				storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore.getShowOccurrencesType());
+				Log.debug("Not Is View Column");
+				connectionField.setVisible(false);
+				btnDisconnect.setVisible(false);
 				toolBarHead.forceLayout();
 			}
+
 		}
 
 	}
@@ -569,11 +585,20 @@ public class ReplaceBatchPanel extends FramedPanel implements
 				});
 	}
 
+	/**
+	 * 
+	 * @param showType
+	 */
 	protected void updateShowType(ShowOccurrencesTypeElement showType) {
 		showOccurencesType = showType.getType();
 		loader.load();
 	}
 
+	/**
+	 * 
+	 * @param loadConfig
+	 * @param callback
+	 */
 	protected void loadData(ListLoadConfig loadConfig,
 			final AsyncCallback<ListLoadResult<ReplaceEntry>> callback) {
 
@@ -792,7 +817,7 @@ public class ReplaceBatchPanel extends FramedPanel implements
 					connection.getName(), connection.getColumnId(),
 					connection.getLabel(), currentReplaceEntry.getRowId(), 0, 0);
 			DimensionRowSelectionDialog dialogDimensionRowSelection = new DimensionRowSelectionDialog(
-					connection, cellData, eventBus);
+					connection, cellData, true, eventBus);
 			dialogDimensionRowSelection.addListener(this);
 			dialogDimensionRowSelection.show();
 		}
@@ -819,13 +844,14 @@ public class ReplaceBatchPanel extends FramedPanel implements
 			}
 			Log.debug("Col: " + col + ", CellData:" + cellData);
 			DimensionRowSelectionDialog dialogDimensionRowSelection;
-			
-			switch (conditionCode){
+
+			switch (conditionCode) {
 			case AllowedColumnType:
 				break;
 			case AmbiguousValueOnExternalReference:
 				dialogDimensionRowSelection = new DimensionRowSelectionDialog(
-						col, cellData, workOnTable, true, true, true, false, eventBus);
+						col, cellData, workOnTable, true, true, true, false,
+						eventBus);
 				dialogDimensionRowSelection.addListener(this);
 				dialogDimensionRowSelection.show();
 				break;
@@ -867,9 +893,9 @@ public class ReplaceBatchPanel extends FramedPanel implements
 				dialogDimensionRowSelection.addListener(this);
 				dialogDimensionRowSelection.show();
 				break;
-			
+
 			}
-			
+
 		} else {
 			cellData = new CellData(currentReplaceEntry.getValue(),
 					column.getName(), column.getColumnId(), column.getLabel(),
@@ -1005,4 +1031,38 @@ public class ReplaceBatchPanel extends FramedPanel implements
 
 	}
 
+	protected void retrieveConnectionForViewColumn(RefColumn refCol) {
+		Log.debug("Retrieve Connection For View Column: " + refCol);
+		TDGWTServiceAsync.INSTANCE.getConnection(refCol,
+				new AsyncCallback<ColumnData>() {
+
+					public void onFailure(Throwable caught) {
+						if (caught instanceof TDGWTSessionExpiredException) {
+							eventBus.fireEvent(new SessionExpiredEvent(
+									SessionExpiredType.EXPIREDONSERVER));
+						} else {
+							Log.error("load column failure:"
+									+ caught.getLocalizedMessage());
+							UtilsGXT3.alert("Error retrieving connection",
+									"Error retrieving connection column");
+						}
+					}
+
+					public void onSuccess(ColumnData result) {
+						Log.debug("Column: " + result);
+						connection = result;
+						setConnectionForViewColumn();
+					}
+
+				});
+
+	}
+
+	protected void setConnectionForViewColumn() {
+		Log.debug("Selected connection: " + connection);
+		connectionField.setValue(connection.getLabel());
+		connectionField.setVisible(true);
+		toolBarHead.forceLayout();
+	}
+
 }
